import torch

def print_hi():
	print('hi')

def print_hello():
	print('hello')

def synthetic_data(w,b,num_examples):
    X = torch.normal(0,1,(num_examples,len(w)))
    y = torch.matmul(X,w)+b
    y+=torch.normal(0,0.01,y.shape)
    return X,y.reshape((-1,1))

if __name__=='__main__':
	print_hi()


from setuptools import setup, find_packages

requirements = [
    'jupyter',
    'numpy',
    'matplotlib',
    'requests',
    'pandas'
]

setup(
    name='oucoffee',
    version='0.0.9',
    python_requires='>=3.6',
    author='Oucoffee Developers',
    author_email='282832606@qq.com',
    url='https://github.com/YiguoWang/oucoffee',
    description='Dive into Deep Learning',
    license='MIT-0',
    packages=find_packages(),
    zip_safe=True,
    install_requires=requirements,
)
